@@ -213,6 +213,22 @@ class Updatable(Resource):
         """
         response = client.certs(f'/{cls._resource}/{id}/certificate', data, files)
         return cls._from_dict(response)
+    
+    @classmethod
+    def _update_logo(cls, id: str, files:Any) -> Resource:
+        """Update an specific resource with new data.
+
+        Performs a PUT request with the updated data.
+
+        Args:
+            id: The ID of the resource.
+
+        Returns:
+            Resource: The updated resource.
+
+        """
+        response = client.logo(f'/{cls._resource}/{id}/logo', files)
+        return cls._from_dict(response)
 
 
 
